@@ -313,7 +313,7 @@ use crate::glbackend::{GLBackendGLRS, GLBackendGlow};
 use crate::glwrapper::{GLContextManager, GLVersion};
 use crate::image::{ImageDataType, ImageHandle, ImageSmoothingMode};
 use crate::renderer2d::Renderer2D;
-use crate::shape::Rectangle;
+use crate::shape::{Polygon, Rectangle};
 #[cfg(target_arch = "wasm32")]
 use crate::web::WebCanvasElement;
 #[cfg(any(doc, doctest, feature = "windowing"))]
@@ -805,6 +805,18 @@ impl Graphics2D
         self.renderer.draw_text(position, color, text);
     }
 
+    /// Draws a polygon with a single color, with the specified offset in
+    /// pixels.
+    pub fn draw_polygon<V: Into<Vector2<f32>>>(
+        &mut self,
+        polygon: &Polygon,
+        offset: V,
+        color: Color
+    )
+    {
+        self.renderer.draw_polygon(polygon, offset, color)
+    }
+
     /// Draws a triangle with the specified colors (one color for each corner).
     ///
     /// The vertex positions (and associated colors) must be provided in
