@@ -279,9 +279,17 @@ impl<UserEventType: 'static> WindowGlutin<UserEventType>
         let event_loop: EventLoop<UserEventGlutin<UserEventType>> =
             EventLoop::with_user_event();
 
-        let primary_monitor = event_loop.primary_monitor().ok_or_else(|| {
-            BacktraceError::new(WindowCreationError::PrimaryMonitorNotFound)
-        })?;
+        let primary_monitor = event_loop
+            .primary_monitor()
+            .or_else(|| {
+                log::error!(
+                    "Couldn't find primary monitor. Using first available monitor."
+                );
+                event_loop.available_monitors().next()
+            })
+            .ok_or_else(|| {
+                BacktraceError::new(WindowCreationError::PrimaryMonitorNotFound)
+            })?;
 
         for (num, monitor) in event_loop.available_monitors().enumerate() {
             log::debug!(
@@ -304,6 +312,8 @@ impl<UserEventType: 'static> WindowGlutin<UserEventType>
             .with_resizable(options.resizable)
             .with_always_on_top(options.always_on_top)
             .with_maximized(options.maximized)
+            .with_visible(false)
+            .with_transparent(options.transparent)
             .with_decorations(options.decorations);
 
         match &options.mode {
@@ -336,16 +346,24 @@ impl<UserEventType: 'static> WindowGlutin<UserEventType>
             }
         });
 
-        match &options.mode {
-            WindowCreationMode::Windowed { position, .. } => {
-                if let Some(position) = position {
-                    position_window(&primary_monitor, window_context.window(), position);
-                }
-            }
+        if let WindowCreationMode::Windowed {
+            position: Some(position),
+            ..
+        } = &options.mode
+        {
+            position_window(&primary_monitor, window_context.window(), position);
+        }
 
-            WindowCreationMode::FullscreenBorderless => {
-                // Nothing to do
-            }
+        // Show window after positioning to avoid the window jumping around
+        window_context.window().set_visible(true);
+
+        // Set the position again to work around an issue on Linux
+        if let WindowCreationMode::Windowed {
+            position: Some(position),
+            ..
+        } = &options.mode
+        {
+            position_window(&primary_monitor, window_context.window(), position);
         }
 
         let glow_context = unsafe {
